package ink.wgink.module.file.media.controller.api.video;

import ink.wgink.common.base.DefaultBaseController;
import ink.wgink.exceptions.PropertiesException;
import ink.wgink.interfaces.consts.ISystemConstant;
import ink.wgink.module.file.media.service.video.IVideoService;
import ink.wgink.pojo.result.ErrorResult;
import ink.wgink.pojo.result.SuccessResultData;
import ink.wgink.properties.media.MediaProperties;
import io.swagger.annotations.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import java.util.concurrent.Callable;

/**
 * When you feel like quitting. Think about why you started
 * 当你想要放弃的时候，想想当初你为何开始
 *
 * @ClassName: VideoController
 * @Description: 视频
 * @Author: WangGeng
 * @Date: 2021/6/8 22:05
 * @Version: 1.0
 **/
@Api(tags = ISystemConstant.API_TAGS_SYSTEM_PREFIX + "视频接口")
@RestController
@RequestMapping(ISystemConstant.API_PREFIX + "/video")
public class VideoController extends DefaultBaseController {

    @Autowired
    private MediaProperties mediaProperties;
    @Autowired
    private IVideoService videoService;

    @ApiOperation(value = "上传视频", notes = "上传视频接口")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "video", value = "文件video", paramType = "query")
    })
    @ApiResponses({@ApiResponse(code = 400, message = "请求失败", response = ErrorResult.class)})
    @PostMapping("upload")
    public Callable<SuccessResultData<String>> upload(@RequestParam("video") MultipartFile video) {
        if (StringUtils.isBlank(mediaProperties.getUploadPath())) {
            throw new PropertiesException("未设置文件上传路径");
        }
        if (StringUtils.isBlank(mediaProperties.getFfmpegPath())) {
            throw new PropertiesException("未设置解码器路径");
        }
        return () -> new SuccessResultData<>(videoService.upload(video));
    }

}
