package ink.wgink.module.file.media.service.video.impl;

import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.exceptions.FileException;
import ink.wgink.module.file.media.manager.MediaManager;
import ink.wgink.module.file.media.manager.domain.MusicMetaInfo;
import ink.wgink.module.file.media.manager.domain.VideoMetaInfo;
import ink.wgink.module.file.media.pojo.vos.video.VideoVO;
import ink.wgink.module.file.media.service.IMediaService;
import ink.wgink.module.file.media.service.video.IVideoService;
import ink.wgink.properties.media.MediaProperties;
import ink.wgink.util.UUIDUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.File;

/**
 * When you feel like quitting. Think about why you started
 * 当你想要放弃的时候，想想当初你为何开始
 *
 * @ClassName: VideoServiceImpl
 * @Description: 视频
 * @Author: WangGeng
 * @Date: 2021/6/8 22:12
 * @Version: 1.0
 **/
@Service
public class VideoServiceImpl extends DefaultBaseService implements IVideoService {

    @Autowired
    private IMediaService mediaService;
    @Autowired
    private MediaProperties mediaProperties;

    @Override
    public String save(VideoVO videoVO) {
        return null;
    }

    @Override
    public String save(String token, VideoVO videoVO) {
        String fileId = UUIDUtil.getUUID();

        return null;
    }

    @Override
    public String upload(MultipartFile video) {
        return upload(null, video);
    }

    @Override
    public String upload(String token, MultipartFile video) {
        String filePath = mediaProperties.getUploadPath() + File.separator + VIDEO_PATH;
        String fileName = video.getOriginalFilename();
        long fileSize = video.getSize();
        String fileType = mediaService.getFileType(fileName);
        String fileMd5 = mediaService.upload(video, filePath, fileName);
        String fileFullPath = filePath;
        // 构建视频内容
        VideoVO videoVO = new VideoVO();
        videoVO.setFileName(fileName);
        videoVO.setFileFullPath(fileFullPath);
        videoVO.setFilePath(VIDEO_PATH);
        videoVO.setFileSize(fileSize);
        videoVO.setFileType(fileType);
        videoVO.setFileMd5(fileMd5);

        File uploadFile = new File(fileFullPath + File.separator + fileName);
        VideoMetaInfo videoMetaInfo = MediaManager.getInstance().getVideoMetaInfo(uploadFile);
        if (videoMetaInfo == null) {
            throw new FileException("上传失败");
        }
        videoVO.setDuration(videoMetaInfo.getDuration());
        videoVO.setWidth(videoMetaInfo.getWidth());
        videoVO.setHeight(videoMetaInfo.getHeight());
        videoVO.setBitRate(videoMetaInfo.getBitRate());
        videoVO.setEncoder(videoMetaInfo.getEncoder());
        videoVO.setFrameRate(videoMetaInfo.getFrameRate());

        MusicMetaInfo musicMetaInfo = videoMetaInfo.getMusicMetaInfo();
        if (musicMetaInfo != null) {
            videoVO.setAudioDuration(musicMetaInfo.getDuration());
            videoVO.setAudioBitRate(musicMetaInfo.getBitRate());
            videoVO.setAudioSampleRate(musicMetaInfo.getSampleRate());
        }
        String fileId = save(token, videoVO);
        // 转码
        return fileId;
    }

}
